####################################################
#              Mapping for Conilurus               #
####################################################

# Clear environment and set up working dir and datestamp
rm(list = ls())
setwd("E:/postdoc")
currentDate <- Sys.Date() # Add current date to environment for output of file names with date
options(scipen = 999) #prevent display in scientific notation


# Read in file containing all sample data
samplist <- read.csv("samples/Master_list_all_samps_bvtd_230620.csv", header=TRUE,row.names=NULL)

# Fix structure
str(samplist)
samplist$notes <- as.character(samplist$notes)
if (!require("lubridate")) install.packages("lubridate")
samplist$datesampled <- dmy(samplist$datesampled) # changes to year-month-day

# Remove samples without species level identification
dodgy <- c((grep("?",samplist$species, fixed=TRUE)),(grep("sp.",samplist$species, fixed=TRUE)))
samplist <- samplist[-dodgy,]

# Load mapping packages
if (!require("ggplot2")) install.packages("ggplot2")
if (!require("mapdata")) install.packages("mapdata")
if (!require("ggsn")) install.packages("ggsn")

# Set up limits of maps to save time
samplist <- samplist[!is.na(samplist$latitude),] # Shouldn't be any missing values but just in case
xmin <- floor(min(samplist$longitude))-1
xmax <- ceiling(max(samplist$longitude))+1
ymin <- floor(min(samplist$latitude))-1
ymax <- ceiling(max(samplist$latitude))+1






### Brush-tailed rabbit-rat sample map

# Obtain mean values for lat and long
str(samplist)
conilist <- samplist[samplist$species=="Conilurus penicillatus",]
meanlatlong <- aggregate(conilist[, 7:8], list(conilist$population), mean)

# Count number of rows/samples per population
library(plyr)
numsamps <- count(conilist$population)
colnames(numsamps) <- c("Group.1","freq")

# Combine dfs
sum.sites <- merge(numsamps,meanlatlong,by="Group.1")
colnames(sum.sites) <- c("population","sampsize","latitude","longitude")

# set up limits of map
xmin <- floor(min(conilist$longitude))-1
xmax <- ceiling(max(conilist$longitude))+1
ymin <- floor(min(conilist$latitude))-1
ymax <- ceiling(max(conilist$latitude))

# create basemap
w2hr <- map_data("world2Hires", xlim = c(xmin,xmax), ylim = c(ymin,ymax), lforce="e") # Featureless

# Get kakadu polygon
library(raster)
library(rgdal)
kak <- readOGR("E:/conilurus_genetics/output/kak_poly","knp_poly")



# ## Get alpha hulls of historical and contemporary records
# if (!require("ALA4R")) install.packages("ALA4R")
# library(ALA4R)
# 
# # Set up some stuff
# ala_config(download_reason_id=7)
# ala_config(warn_on_empty=TRUE)

# Extract all records of target species from ALA
# # Extract all records
# ala_mammals <- occurrences(taxon="taxon_name:\"Conilurus penicillatus\"",
#                            wkt="POLYGON((121.5 -19, 138 -19, 138 -10.94, 121.5 -10.94, 121.5 -19))",
#                            fields=c("latitude","longitude","taxon_name","common_name","coordinate_uncertainty","year","occurrence_date","collector",
#                                     "individual_count","cl1048"),
#                            email="brenton.vtd@gmail.com")
# 
# summary(ala_mammals)

# Save to avoid re-extracting data from the stupidly slow ALA
# write.csv(ala_mammals$data,"E:/conilurus_genetics/output/ala_mammals_data.csv",row.names = FALSE)
species <- read.csv("E:/conilurus_genetics/output/ala_mammals_data.csv")

species <- species[,c("scientificName","commonName","latitude","longitude","coordinateUncertaintyInMetres","year")]

# # Filter out poor quality records
# species <- species[!is.na(species$longitude) & !is.na(species$latitude), ] # remove incomplete - does nothing
# species <- species[!is.na(species$year),] # remove w/out dates
# species <- species[species$coordinateUncertaintyInMetres<500 | is.na(species$coordinateUncertaintyInMetres) , ] # remove inaccurate
# species <- species[!is.na(species$scientificName), ] # remove any records missing scientific name - does nothing


# Only filter on dates for contemporary alpha hull
modernrecords <- 2000
species <- species[species$year >= modernrecords,] # Contemporary dataset

# Remove duplicate records from background sampling and year column from species of interest
species$year <- NULL
species$coordinateUncertaintyInMetres <- NULL
species <- species[!duplicated(species), ]

# Create alpha shape
library("alphahull")
alshape <- ashape(x=species$longitude, y=species$latitude, alpha = 2)
plot(alshape)

# Convert alpha shape to spatial polygons
source("E:/mammal_niche_change/sdms/alpha2spatial_function.R")
library(sf)
hullpoly <- ashape_to_SPLDF(alshape, proj4string="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0")
hullpoly <- st_as_sf(hullpoly)
hullpoly <- st_polygonize(hullpoly)
hullpoly <- st_cast(hullpoly)
hullpoly <- as(hullpoly, "Spatial")

# check plotting ok
plot(hullpoly)

# convert to raster
library(raster)
xmin <- 121.5
xmax <- 138
ymin <- -19
ymax <- -10.94
ex <- extent(xmin,xmax,ymin,ymax)
annualrain <- raster("E:/mammal_niche_change/sdms/all_unified_layers/annualrain.tif")
annualrain <- crop(annualrain, ex)
hullras <- rasterize(hullpoly, annualrain)
hullras[hullras > 0] <- 1

# clip to coastline
library(sf)
dsn <- "E:/postdoc/chris/mapping/nsaasr9nnd_02211a04ec_alb132"
lay <- "aust_cd66states"
coast <- read_sf(dsn = dsn, layer = lay) # Read in coastline
library(fasterize) # Convert to raster with same extent and resolution as annualrain
coast <- fasterize(coast, hullras, field = NULL, background = NA)
hullras <- mask(hullras, coast)

# Check mapping
plot(annualrain, xlim=c(121.5,138), ylim=c(-19,-11))
plot(hullras,add=TRUE)

# Crop to reasonable extent and then mask to shape
hullex <- extent(121.5,138,-16,-10.94)
hullras <- crop(hullras, hullex)

# Convert raster to polygons for easy plotting
library(stars)
hullpolyhist <- st_as_stars(hullras) %>% 
  st_as_sf(merge = TRUE) # this is the raster to polygons part

# check plotting
plot(annualrain, xlim=c(121.5,138), ylim=c(-19,-11))
plot(hullpolyhist,add=TRUE)

# run the above again with contemporary occurrences only

# now make the contemporary polygons for plotting
hullpolycon <- st_as_stars(hullras) %>% 
  st_as_sf(merge = TRUE) # this is the raster to polygons part


# set up limits of map again
xmin <- floor(min(conilist$longitude))-1
xmax <- ceiling(max(conilist$longitude))+1
ymin <- floor(min(conilist$latitude))-1
ymax <- ceiling(max(conilist$latitude))


## Plot everything on map
library(ggrepel)
library(ggsn)
library(ggplot2)
# Adjust scalebar and north arrow scale as needed
con_map <- ggplot() +
  geom_polygon(data = w2hr, aes(x=long, y = lat, group = group), fill = "grey90", color = "grey30", size=0.1) + 
  coord_fixed(1) +
  coord_equal(expand=FALSE) +
  # geom_tile(data=hulldf, aes(x=long, y=lat), fill=NA, colour="#99CCFF", linetype=1) +
  # geom_tile(data=hulldfcon, aes(x=long, y=lat), fill=NA, colour="#0080FF", linetype=1) +
  theme_bw() +
  scale_alpha(guide = "none") +
  theme(panel.grid=element_blank()) +
  xlab("Longitude") +
  ylab("Latitude") +
  theme(axis.title.y=element_text(size=14, margin=margin(0,16,0,0)),
        axis.title.x=element_text(size=14, margin=margin(16,0,0,0)),
        axis.text = element_text(size = 14, color="black")) +
  geom_sf(data=hullpolyhist, colour="#99CCFF", fill="#99CCFF", size=0.1, linetype=1) +
  geom_sf(data=hullpolycon, colour="#0080FF", fill="#0080FF", size=0.1, linetype=1) +
  geom_polygon(data=fortify(kak), aes(long,lat,group=group), fill=NA, colour="black", size=0.1, linetype=2) +
  geom_point(data = sum.sites, aes(x = longitude, y = latitude), color = "black",
             size = sqrt(sum.sites$sampsize)*1.8, pch=21, fill="yellow") +
  geom_text_repel(aes(x = sum.sites$longitude, y = sum.sites$latitude, label=sum.sites$population),
                  force=1, point.padding=0.5, segment.color = "transparent", colour="red") +
  north(location = "topleft", scale = 0.15, symbol = 1,
        y.min=ymin, y.max=ymax, x.min=xmin, x.max=xmax,
        anchor = c(x=xmin, y=ymax-(2/100*(xmax-xmin)))) +
  ggsn::scalebar(location="bottomleft",y.min=ymin, y.max=ymax, x.min=xmin, x.max=xmax, 
                 dist=200, dist_unit="km", transform=TRUE, model='WGS84',
                 anchor = c(x = xmax-5, y = ymin+0.2), st.color="black", st.dist=-0.05, st.size=3) +
  scale_y_continuous(breaks=c(-18, -16, -14, -12)) +
  scale_x_continuous(breaks=c(125,130,135,140)) +
  annotate("text",x=133.55,y=-13,label="Kakadu NP", colour="red")
# annotate("segment", x=137.5, xend=136.51, y=-13.6, yend=-13.98, colour="black", size=0.8, alpha=1, arrow=arrow())

con_map


ggsave("E:/conilurus_genetics/output/btrr_all_samps_310820.pdf")

# Output conilurus pdf for manuscript
pdffilename <- paste("E:/conilurus_genetics/output/btrr_samp_map",currentDate,".pdf",sep="")
pdf(pdffilename, family="Times", width=9, height=7)
con_map
dev.off()

